<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ug">
<context>
    <name>Action</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="188"/>
        <source>Display in file manager</source>
        <translation>ھۆججەت باشقۇرغۇچتا كۆرسىتىش</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="489"/>
        <source>Clear log</source>
        <translation>خاتىرىنى تازىلاش</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="189"/>
        <source>Refresh</source>
        <translation>يېڭىلاش</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="539"/>
        <source>Are you sure you want to clear the log?</source>
        <translation>بۇ خاتىرىنى راستلا ئۆچۈرمەكچىمۇ؟</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="540"/>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="541"/>
        <source>Confirm</source>
        <translation>جەزملەش</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <location filename="../application/filtercontent.cpp" line="80"/>
        <source>All</source>
        <translation>ھەممىسى</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="83"/>
        <source>Today</source>
        <translation>بۈگۈن</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="86"/>
        <source>3 days</source>
        <translation>3كۈن</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="89"/>
        <source>1 week</source>
        <translation>1 ھەپتە</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="92"/>
        <source>1 month</source>
        <translation>1 ئاي</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="95"/>
        <source>3 months</source>
        <translation>3 ئاي</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="224"/>
        <source>Export</source>
        <comment>button</comment>
        <translation>چىقىرىش</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <location filename="../application/filtercontent.cpp" line="120"/>
        <source>All</source>
        <translation>ھەممىسى</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="121"/>
        <source>Emergency</source>
        <translation>جىددىي</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="122"/>
        <source>Alert</source>
        <translation>ئېغىر ئاگاھلاندۇرۇش</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="123"/>
        <source>Critical</source>
        <translation>ئېغىر</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="124"/>
        <source>Error</source>
        <translation>خاتالىق</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="125"/>
        <source>Warning</source>
        <translation>ئاگاھلاندۇرۇش</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="126"/>
        <source>Notice</source>
        <translation>دىققەت</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="127"/>
        <source>Info</source>
        <translation>ئۇچۇرى</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="128"/>
        <source>Debug</source>
        <translation>سىناپ تەڭشەش</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="198"/>
        <source>Login</source>
        <translation>كىرىش</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="199"/>
        <source>Boot</source>
        <translation>قوزغىتىش</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="200"/>
        <source>Shutdown</source>
        <translation>تاقاش</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="142"/>
        <source>Super critical</source>
        <translation>ئىنتايىن ئېغىر</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="148"/>
        <source>Trace</source>
        <translation>ئىز قوغلاش</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="212"/>
        <source>Identity authentication</source>
        <translation>سالاھىيەت پەرقلەندۈرۈش</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="213"/>
        <source>Discretionary Access Control</source>
        <translation>ئۆز ئالدىغا زىيارەت قىلىشنى كونتروللاش</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="214"/>
        <source>Mandatory access control</source>
        <translation>مەجبۇرىي زىيارەتنى قىلىشنى كونتروللاش</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="215"/>
        <source>Remote</source>
        <translation>يىراقتىن ئۇلاش</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="216"/>
        <source>Document audit</source>
        <translation>ھۆججەت تەكشۈرۈش</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="217"/>
        <source>Other</source>
        <translation>باشقا</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="1800"/>
        <source>zip(*.zip)</source>
        <translation>zip (*.zip)</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="1794"/>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <location filename="../application/exportprogressdlg.cpp" line="35"/>
        <source>Exporting...</source>
        <translation>چىقىرىۋاتىدۇ...</translation>
    </message>
    <message>
        <location filename="../application/exportprogressdlg.cpp" line="58"/>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="3257"/>
        <source>Export successful</source>
        <translation>چىقىرىلدى</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3260"/>
        <source>Export failed</source>
        <translation>ھۆججەتننى چىقىرالمىدى</translation>
    </message>
    <message>
        <location filename="../application/logbackend.cpp" line="1763"/>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation>چىقىرىدىغان مۇندەرىجىنى ئىشلەتكىلى بولمايدۇ، باشقا مۇندەرىجە تاللاپ مەشغۇلات قىلىڭ</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="1792"/>
        <source>Export File</source>
        <translation>ھۆججەت چىقىرىش</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <location filename="../application/filtercontent.cpp" line="76"/>
        <source>Period:</source>
        <translation>دەۋرىيلىكى:</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="114"/>
        <source>Level:  </source>
        <translation>دەرىجىسى:</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="180"/>
        <source>Status:</source>
        <translation>ھالىتى:</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="193"/>
        <source>Event Type:</source>
        <translation>پائالىيەت تىپى:</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="132"/>
        <source>User:</source>
        <translation>ئىشلەتكۈچى نامى:</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="134"/>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="138"/>
        <source>Action:</source>
        <translation>مەشغۇلات:</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="143"/>
        <source>Username:</source>
        <translation>ئىشلەتكۈچى نامى:</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="469"/>
        <source>Boot record</source>
        <translation>قوزغىتىش خاتىرىسى</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="471"/>
        <source>Shutdown record</source>
        <translation>تاقاش خاتىرىسى</translation>
    </message>
    <message>
        <location filename="../application/logdetailinfowidget.cpp" line="474"/>
        <source>Login record</source>
        <translation>كىرىش خاتىرىسى</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="208"/>
        <source>Audit Type:</source>
        <translation>تەكشۈرۈش تىپى:</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="155"/>
        <source>Application:</source>
        <translation>ئەپ:</translation>
    </message>
    <message>
        <location filename="../application/filtercontent.cpp" line="167"/>
        <source>Submodule:</source>
        <translation>بالا مودېل:</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="201"/>
        <source>Warning</source>
        <translation>ئاگاھلاندۇرۇش</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="202"/>
        <source>Debug</source>
        <translation>سىناپ تەڭشەش</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="203"/>
        <source>Info</source>
        <translation>ئۇچۇرى</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="204"/>
        <source>Error</source>
        <translation>خاتالىق</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="208"/>
        <source>Emergency</source>
        <translation>جىددىي</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="209"/>
        <source>Alert</source>
        <translation>ئېغىر ئاگاھلاندۇرۇش</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="210"/>
        <source>Critical</source>
        <translation>ئېغىر</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="213"/>
        <source>Notice</source>
        <translation>دىققەت</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="220"/>
        <source>Trace</source>
        <translation>ئىز قوغلاش</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="226"/>
        <source>Super critical</source>
        <translation>ئىنتايىن ئېغىر</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <location filename="../application/logauththread.cpp" line="529"/>
        <source>Log file is empty</source>
        <translation>خاتىرە ھۆججەت قۇرۇق</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../application/main.cpp" line="329"/>
        <source>Log Viewer</source>
        <translation>خاتىرە كۆرگۈچ</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="332"/>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>خاتىرە يىغىش قورالى سىستېما خاتىرىسىنى كۆرسىتىدىغان كىچىك قورال.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="120"/>
        <source>No search results</source>
        <translation>ئىزدەش نەتىجىسى يوق</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="109"/>
        <source>Search</source>
        <translation>ئىزدەش</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="563"/>
        <source>Level</source>
        <translation>دەرىجىسى</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="564"/>
        <source>Process</source>
        <translation>جەريان</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="565"/>
        <source>Date and Time</source>
        <translation>ۋاقىت</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="566"/>
        <source>Info</source>
        <translation>ئۇچۇرى</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="567"/>
        <source>User</source>
        <translation>ئىشلەتكۈچى نامى</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="568"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="953"/>
        <source>Source</source>
        <translation>مەنبە</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="669"/>
        <source>Action</source>
        <translation>مەشغۇلات</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3374"/>
        <source>Status</source>
        <translation>ھالىتى</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="1140"/>
        <source>Event Type</source>
        <translation>پائالىيەت تىپى</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="1141"/>
        <source>Username</source>
        <translation>كىرىش نامى</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="897"/>
        <source>Level:</source>
        <translation>دەرىجىسى:</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="898"/>
        <source>Process:</source>
        <translation>جەريان:</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="899"/>
        <source>Date and Time:</source>
        <translation>ۋاقىت:</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="901"/>
        <source>Info:</source>
        <translation>ئۇچۇر:</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="902"/>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="906"/>
        <source>User:</source>
        <translation>ئىشلەتكۈچى نامى:</translation>
    </message>
    <message>
        <location filename="../application/logexportthread.cpp" line="907"/>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3532"/>
        <source>File Name</source>
        <translation>ھۆججەت نامى</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3533"/>
        <source>Time Modified</source>
        <translation>ئۆزگەرتكەن ۋاقىت:</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3741"/>
        <source>SIG</source>
        <translation>سىگنال</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3745"/>
        <source>EXE</source>
        <translation>پىروگرامما</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3743"/>
        <source>Core File</source>
        <translation>يادرولۇق ھۆججەت</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3744"/>
        <source>User Name </source>
        <translation>ئىشلەتكۈچى</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="1009"/>
        <source>Offset</source>
        <translation>پىروگرامما</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="1142"/>
        <source>Date and Time</source>
        <translation>ۋاقىت</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <location filename="../application/loglistview.cpp" line="171"/>
        <source>System Log</source>
        <translation>سىستېما خاتىرىسى</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="182"/>
        <source>Kernel Log</source>
        <translation>ئىچكى يادرو خاتىرىسى</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="203"/>
        <source>Boot Log</source>
        <translation>قوزغىتىش خاتىرىسى</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="232"/>
        <source>dpkg Log</source>
        <translation>dpkg خاتىرىسى</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="244"/>
        <source>Kwin Log</source>
        <translation>Kwin خاتىرىسى</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="253"/>
        <source>Xorg Log</source>
        <translation>Xorg خاتىرىسى</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="265"/>
        <source>Application Log</source>
        <translation>ئەپلەر خاتىرىسى</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="290"/>
        <source>Boot-Shutdown Event</source>
        <translation>ئېچىش-تاقاش مەشغۇلاتى</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="222"/>
        <source>dnf Log</source>
        <translation>dnf خاتىرىسى</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="303"/>
        <source>Other Log</source>
        <translation>باشقا كۈندىلىك خاتىرە</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="339"/>
        <source>Custom Log</source>
        <translation>كۈندىلىك خاتىرە بەلگىلەش</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="319"/>
        <source>Audit Log</source>
        <translation>تەكشۈرۈش خاتىرىسى</translation>
    </message>
    <message>
        <location filename="../application/loglistview.cpp" line="278"/>
        <source>Coredump Log</source>
        <translation>گۇم بولۇش خاتىرىسى</translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="133"/>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation>ئۇچۇرنى ئالالمىدى، systemd-coredump قاچىلاڭ.</translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <location filename="../application/displaycontent.cpp" line="139"/>
        <source>You do not have permission to view it</source>
        <translation>كۆرۈش ھوقۇقى يوق</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="127"/>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation>نۆۋەتتىكى سىستېما بىخەتەرلىك دەرىجىسى: يۇقىرى
تەكشۈرگۈچى باشقۇرغۇچىلا تەكشۈرۈش خاتىرىسىنى كۆرەلەيدۇ</translation>
    </message>
    <message>
        <location filename="../application/displaycontent.cpp" line="3216"/>
        <source>Audit log is not exist.</source>
        <translation>ئەھەمچىلىك ھەجىمى ئىشلەمەيدۇ</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../application/main.cpp" line="67"/>
        <source>Export logs to the specified path</source>
        <translation>خاتىرىنى بەلگىلىگەن مۇندەرىجىگە چىقىرىش</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="67"/>
        <source>PATH</source>
        <translation>چىقىرىش مۇندەرىجىسى</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="68"/>
        <source>Export logs of specified types</source>
        <translation>خاتىرە تۈرى بويىچە چىقىرىش</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="68"/>
        <source>TYPE</source>
        <translation>خاتىرە تۈرى</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="69"/>
        <source>Export logs of specified self-developed applications</source>
        <translation>خاتىرىنى ئۆز ئالدىغا ئاچقان ئەپ بويىچە چىقىرىش</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="69"/>
        <source>SELF APPNAME</source>
        <translation>ئۆز ئالدىغا ئاچقان  ئەپ نامى</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="70"/>
        <source>Export logs within a specified time period</source>
        <translation>خاتىرىنى ۋاقىت دەۋرىيلىكى بويىچە چىقىرىش</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="70"/>
        <source>PERIOD</source>
        <translation>دەۋرىيلىكى</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="71"/>
        <source>Export logs within a specified debug level</source>
        <translation>خاتىرىنى تەڭشەش-سىناش دەرىجىسى بويىچە چىقىرىش</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="71"/>
        <source>LEVEL</source>
        <translation>تەڭشەش-سىناش دەرىجىسى</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="72"/>
        <source>BOOT STATUS</source>
        <translation>قوزغىلىش ھالىتى</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="72"/>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation>قوزغىلىش خاتىرىسىنى ھالىتى بويىچە چىقىرىش(klu)</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="73"/>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation>ئېچىش-تاقاش خاتىرىسى/تەكشۈرۈش خاتىرىسىنى مەشغۇلات تۈرى بويىچە چىقىرىش</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="73"/>
        <source>EVENT TYPE</source>
        <translation>مەشغۇلات تۈرى</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="74"/>
        <source>Export logs based on keywords search results</source>
        <translation>خاتىرىنى ھالقىلىق سۆز بويىچە چىقىرىش</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="74"/>
        <source>KEY WORD</source>
        <translation>ھالقىلىق سۆز</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="76"/>
        <source>Report coredump informations.</source>
        <translation>گۇم بولۇش نۇقتىسىنىڭ ئۇچۇرىنى يوللاش</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="75"/>
        <source>Export logs based on app submodel</source>
        <translation>خاتىرىنى بالا مودېل بويىچە چىقىرىش</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="75"/>
        <source>SUBMODULE</source>
        <translation>بالا مودېل</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <location filename="../application/logcollectormain.cpp" line="202"/>
        <source>Refresh interval</source>
        <translation>يېڭىلاش چاستوتىسى</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="204"/>
        <source>10 sec</source>
        <translation>ھەر 10 سېكۇنت</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="205"/>
        <source>1 min</source>
        <translation>ھەر 1 مىنۇت</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="206"/>
        <source>5 min</source>
        <translation>5 مىنۇت</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="207"/>
        <source>No refresh</source>
        <translation>يېڭىلىمىسۇن</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="234"/>
        <source>Export All</source>
        <translation>ھەممىنى چىقىرىش</translation>
    </message>
    <message>
        <location filename="../application/logcollectormain.cpp" line="240"/>
        <source>Refresh Now</source>
        <translation>ھازىر يېڭىلاش</translation>
    </message>
</context>
</TS>
